pilot.api.api

Package pilot :: Package api :: Module api |

# Source Code for Module pilot.api.api

     1  import compute.api
     2  import data.api
     3
     4 -class PilotError(Exception):
     5 -    def __init__(self, value):
     6          self.value = value
     7
     8 -    def __str__(self):
     9          return repr(self.value)
    10
    11
    12 -class ComputeDataService(compute.api.ComputeUnitService, data.api.PilotDataService):
    13      """ B{ComputeDataService (CDS).}
    14
    15          The ComputeDataService is the application's interface to submit
    16          ComputeUnits and PilotData/DataUnit to the Pilot-Manager
    17          in the P* Model.
    18      """
    19
    20
    21 -    def __init__(self, wds_id=None):
    22          """ Create a Compute Data Service object.
    23
    24              Keyword arguments:
    25              wds_id -- Reconnect to an existing WDS (optional).
    26          """
    27          raise  NotImplementedError("Abstract super class, please use ComputeDataService implementation class in pilot namespace")
    28